=== modified file 'bzrlib/add.py'
--- bzrlib/add.py	2011-12-19 16:41:49 +0000
+++ bzrlib/add.py	2012-01-24 00:16:15 +0000
@@ -131,7 +131,8 @@
         """
 
         if self.base_tree.has_id(parent_ie.file_id):
-            base_parent_ie = self.base_tree.inventory[parent_ie.file_id]
+            # FIXME: Handle nested trees
+            base_parent_ie = self.base_tree.root_inventory[parent_ie.file_id]
             base_child_ie = base_parent_ie.children.get(
                 osutils.basename(path))
             if base_child_ie is not None:

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2012-01-05 09:50:04 +0000
+++ bzrlib/builtins.py	2012-01-24 00:16:15 +0000
@@ -858,7 +858,7 @@
                 (tree.id2path(file_id), tree.inventory[file_id])
                 for file_id in file_ids if tree.has_id(file_id))
         else:
-            entries = tree.inventory.entries()
+            entries = tree.root_inventory.entries()
 
         self.cleanup_now()
         for path, entry in entries:
@@ -2323,14 +2323,13 @@
         self.add_cleanup(wt.lock_read().unlock)
         basis = wt.basis_tree()
         self.add_cleanup(basis.lock_read().unlock)
-        basis_inv = basis.inventory
-        inv = wt.inventory
-        for file_id in inv:
-            if basis_inv.has_id(file_id):
-                continue
-            if inv.is_root(file_id) and len(basis_inv) == 0:
-                continue
-            path = inv.id2path(file_id)
+        root_id = wt.get_root_id()
+        for file_id in wt.all_file_ids():
+            if basis.has_id(file_id):
+                continue
+            if root_id == file_id:
+                continue
+            path = wt.id2path(file_id)
             if not os.access(osutils.pathjoin(wt.basedir, path), os.F_OK):
                 continue
             if null:

=== modified file 'bzrlib/commit.py'
--- bzrlib/commit.py	2011-12-18 12:46:49 +0000
+++ bzrlib/commit.py	2012-01-24 00:16:15 +0000
@@ -667,7 +667,7 @@
         # entries and the order is preserved when doing this.
         if self.use_record_iter_changes:
             return
-        self.basis_inv = self.basis_tree.inventory
+        self.basis_inv = self.basis_tree.root_inventory
         self.parent_invs = [self.basis_inv]
         for revision in self.parents[1:]:
             if self.branch.repository.has_revision(revision):
@@ -834,7 +834,8 @@
         deleted_paths = {}
         # XXX: Note that entries may have the wrong kind because the entry does
         # not reflect the status on disk.
-        work_inv = self.work_tree.inventory
+        # FIXME: Nested trees
+        work_inv = self.work_tree.root_inventory
         # NB: entries will include entries within the excluded ids/paths
         # because iter_entries_by_dir has no 'exclude' facility today.
         entries = work_inv.iter_entries_by_dir(

=== modified file 'bzrlib/mutabletree.py'
--- bzrlib/mutabletree.py	2012-01-06 14:09:04 +0000
+++ bzrlib/mutabletree.py	2012-01-24 00:16:15 +0000
@@ -615,7 +615,7 @@
             # nb: this relies on someone else checking that the path we're using
             # doesn't contain symlinks.
             parent_ie = self._convert_to_directory(parent_ie, inv_dirname)
-        file_id = self.action(self.tree.inventory, parent_ie, path, kind)
+        file_id = self.action(self.tree, parent_ie, path, kind)
         entry = _mod_inventory.make_entry(kind, basename, parent_ie.file_id,
             file_id=file_id)
         self._invdelta[inv_path] = (None, inv_path, entry.file_id, entry)

=== modified file 'bzrlib/repofmt/groupcompress_repo.py'
--- bzrlib/repofmt/groupcompress_repo.py	2011-12-19 19:15:58 +0000
+++ bzrlib/repofmt/groupcompress_repo.py	2012-01-24 00:16:15 +0000
@@ -954,7 +954,7 @@
             else:
                 basis_tree = self.revision_tree(basis_revision_id)
                 basis_tree.lock_read()
-                basis_inv = basis_tree.inventory
+                basis_inv = basis_tree.root_inventory
         try:
             result = basis_inv.create_by_apply_delta(delta, new_revision_id,
                 propagate_caches=propagate_caches)

=== modified file 'bzrlib/revisiontree.py'
--- bzrlib/revisiontree.py	2011-12-30 13:59:00 +0000
+++ bzrlib/revisiontree.py	2012-01-24 00:16:15 +0000
@@ -141,7 +141,7 @@
         # The only files returned by this are those from the version
         if from_dir is None:
             from_dir_id = None
-            inv = self.inventory
+            inv = self.root_inventory
         else:
             inv, from_dir_id = self._path2inv_file_id(from_dir)
             if from_dir_id is None:
@@ -165,8 +165,8 @@
         return inv[inv_file_id].reference_revision
 
     def get_root_id(self):
-        if self.inventory.root:
-            return self.inventory.root.file_id
+        if self.root_inventory.root:
+            return self.root_inventory.root.file_id
 
     def kind(self, file_id):
         inv, inv_file_id = self._unpack_file_id(file_id)
@@ -252,8 +252,8 @@
             and isinstance(target, RevisionTree)):
             try:
                 # Only CHK inventories have id_to_entry attribute
-                source.inventory.id_to_entry
-                target.inventory.id_to_entry
+                source.root_inventory.id_to_entry
+                target.root_inventory.id_to_entry
                 return True
             except AttributeError:
                 pass
@@ -277,7 +277,9 @@
         # to CHKInventory.iter_changes and do a better job there -- vila
         # 20090304
         changed_file_ids = set()
-        for result in self.target.inventory.iter_changes(self.source.inventory):
+        # FIXME: nested tree support
+        for result in self.target.root_inventory.iter_changes(
+                self.source.root_inventory):
             if specific_file_ids is not None:
                 file_id = result[0]
                 if file_id not in specific_file_ids:

=== modified file 'bzrlib/tests/per_repository/test_commit_builder.py'
--- bzrlib/tests/per_repository/test_commit_builder.py	2011-12-22 16:17:28 +0000
+++ bzrlib/tests/per_repository/test_commit_builder.py	2012-01-24 00:16:15 +0000
@@ -49,7 +49,7 @@
         if builder.record_root_entry is True:
             tree.lock_read()
             try:
-                ie = tree.inventory.root
+                ie = tree.root_inventory.root
             finally:
                 tree.unlock()
             parent_tree = tree.branch.repository.revision_tree(

=== modified file 'bzrlib/tree.py'
--- bzrlib/tree.py	2011-12-29 23:15:08 +0000
+++ bzrlib/tree.py	2012-01-24 00:16:15 +0000
@@ -768,6 +768,7 @@
             yield cur_path
         # all done.
 
+    @deprecated_method(deprecated_in((2, 5, 0)))
     def _get_inventory(self):
         return self._inventory
 
@@ -781,14 +782,37 @@
             file_id = file_id[0]
         return self.inventory, file_id
 
+    def _get_root_inventory(self):
+        return self._inventory
+
+    root_inventory = property(_get_root_inventory,
+        doc="Root inventory of this tree")
+
+    def _unpack_file_id(self, file_id):
+        """Find the inventory and inventory file id for a tree file id.
+
+        :param file_id: The tree file id, as bytestring or tuple
+        :return: Inventory and inventory file id
+        """
+        if isinstance(file_id, tuple):
+            if len(file_id) != 0:
+                raise ValueError("nested trees not yet supported: %r" % file_id)
+            file_id = file_id[0]
+        return self.root_inventory, file_id
+
     @needs_read_lock
     def path2id(self, path):
         """Return the id for path in this tree."""
         return self._path2inv_file_id(path)[1]
 
     def _path2inv_file_id(self, path):
-        # for now
-        return self.inventory, self._inventory.path2id(path)
+        """Lookup a inventory and inventory file id by path.
+
+        :param path: Path to look up
+        :return: tuple with inventory and inventory file id
+        """
+        # FIXME: Support nested trees
+        return self.root_inventory, self.root_inventory.path2id(path)
 
     def id2path(self, file_id):
         """Return the path for a file id.
@@ -807,11 +831,12 @@
         return inventory.has_id(file_id)
 
     def all_file_ids(self):
-        return set(self.inventory) # for now
+        return set(
+            [entry.file_id for path, entry in self.iter_entries_by_dir()])
 
     @deprecated_method(deprecated_in((2, 4, 0)))
     def __iter__(self):
-        return iter(self.inventory) # for now
+        return iter(self.all_file_ids())
 
     def filter_unversioned_files(self, paths):
         """Filter out paths that are versioned.
@@ -821,8 +846,7 @@
         # NB: we specifically *don't* call self.has_filename, because for
         # WorkingTrees that can indicate files that exist on disk but that
         # are not versioned.
-        pred = self.inventory.has_filename # for now
-        return set((p for p in paths if not pred(p)))
+        return set((p for p in paths if self.path2id(p) is not None))
 
     @needs_read_lock
     def iter_entries_by_dir(self, specific_file_ids=None, yield_parents=False):
@@ -843,10 +867,12 @@
             inventory_file_ids = []
             for tree_file_id in specific_file_ids:
                 inventory, inv_file_id = self._unpack_file_id(tree_file_id)
-                if not inventory is self.inventory: # for now
-                    raise AssertionError("%r != %r" % (inventory, self.inventory))
+                if not inventory is self.root_inventory: # for now
+                    raise AssertionError("%r != %r" % (
+                        inventory, self.root_inventory))
                 inventory_file_ids.append(inv_file_id)
-        return self.inventory.iter_entries_by_dir(
+        # FIXME: Support nested trees
+        return self.root_inventory.iter_entries_by_dir(
             specific_file_ids=inventory_file_ids, yield_parents=yield_parents)
 
     @deprecated_method(deprecated_in((2, 5, 0)))

=== modified file 'bzrlib/vf_repository.py'
--- bzrlib/vf_repository.py	2012-01-04 16:10:04 +0000
+++ bzrlib/vf_repository.py	2012-01-24 00:16:15 +0000
@@ -604,16 +604,17 @@
                         _mod_revision.NULL_REVISION))
         # The basis inventory from a repository 
         if revtrees:
-            basis_inv = revtrees[0].inventory
+            basis_tree = revtrees[0]
         else:
-            basis_inv = self.repository.revision_tree(
-                _mod_revision.NULL_REVISION).inventory
+            basis_tree = self.repository.revision_tree(
+                _mod_revision.NULL_REVISION)
+        basis_inv = basis_tree.root_inventory
         if len(self.parents) > 0:
             if basis_revision_id != self.parents[0] and not ghost_basis:
                 raise Exception(
                     "arbitrary basis parents not yet supported with merges")
             for revtree in revtrees[1:]:
-                for change in revtree.inventory._make_delta(basis_inv):
+                for change in revtree.root_inventory._make_delta(basis_inv):
                     if change[1] is None:
                         # Not present in this parent.
                         continue
@@ -1021,7 +1022,7 @@
             # return a new inventory, but as there is no revision tree cache in
             # repository this is safe for now - RBC 20081013
             if basis_inv is None:
-                basis_inv = basis_tree.inventory
+                basis_inv = basis_tree.root_inventory
             basis_inv.apply_delta(delta)
             basis_inv.revision_id = new_revision_id
             return (self.add_inventory(new_revision_id, basis_inv, parents),

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2012-01-10 21:43:46 +0000
+++ bzrlib/workingtree.py	2012-01-24 00:16:15 +0000
@@ -1946,10 +1946,6 @@
             if entry.parent_id == orig_root_id:
                 entry.parent_id = inv.root.file_id
 
-    def all_file_ids(self):
-        """See Tree.iter_all_file_ids"""
-        return set(self.inventory)
-
     @needs_tree_write_lock
     def set_parent_trees(self, parents_list, allow_leftmost_as_ghost=False):
         """See MutableTree.set_parent_trees."""
@@ -2084,7 +2080,7 @@
         return osutils.lexists(self.abspath(path))
 
     def has_or_had_id(self, file_id):
-        if file_id == self.inventory.root.file_id:
+        if file_id == self.root_inventory.root.file_id:
             return True
         inv, inv_file_id = self._unpack_file_id(file_id)
         return inv.has_id(inv_file_id)
@@ -2222,7 +2218,8 @@
         # should probably put it back with the previous ID.
         # the read and write working inventory should not occur in this
         # function - they should be part of lock_write and unlock.
-        inv = self.inventory
+        # FIXME: nested trees
+        inv = self.root_inventory
         for f, file_id, kind in zip(files, ids, kinds):
             if file_id is None:
                 inv.add_path(f, kind=kind)
@@ -2758,7 +2755,8 @@
 
         Also does basic plausability tests.
         """
-        inv = self.inventory
+        # FIXME: Handling of nested trees
+        inv = self.root_inventory
 
         for rename_entry in rename_entries:
             # store to local variables for easier reference
@@ -2822,7 +2820,6 @@
         Depending on the value of the flag 'only_change_inv', the
         file will be moved on the file system or not.
         """
-        inv = self.inventory
         moved = []
 
         for entry in rename_entries:
@@ -2850,7 +2847,7 @@
                         " Error message is: %s" % e)
 
     def _move_entry(self, entry):
-        inv = self.inventory
+        inv = self.root_inventory
         from_rel_abs = self.abspath(entry.from_rel)
         to_rel_abs = self.abspath(entry.to_rel)
         if from_rel_abs == to_rel_abs:
@@ -2897,7 +2894,8 @@
 
     def stored_kind(self, file_id):
         """See Tree.stored_kind"""
-        return self.inventory[file_id].kind
+        inv, inv_file_id = self._unpack_file_id(file_id)
+        return inv[inv_file_id].kind
 
     def extras(self):
         """Yield all unversioned files in this WorkingTree.
@@ -2910,7 +2908,7 @@
         This is the same order used by 'osutils.walkdirs'.
         """
         ## TODO: Work from given directory downwards
-        for path, dir_entry in self.inventory.directories():
+        for path, dir_entry in self.root_inventory.directories():
             # mutter("search for unknowns in %r", path)
             dirabs = self.abspath(path)
             if not isdir(dirabs):
@@ -2953,8 +2951,7 @@
         """
         _directory = 'directory'
         # get the root in the inventory
-        inv = self.inventory
-        top_id = inv.path2id(prefix)
+        inv, top_id = self._path2inv_file_id(prefix)
         if top_id is None:
             pending = []
         else:

=== modified file 'bzrlib/workingtree_4.py'
--- bzrlib/workingtree_4.py	2012-01-06 14:09:04 +0000
+++ bzrlib/workingtree_4.py	2012-01-24 00:16:15 +0000
@@ -68,6 +68,10 @@
     realpath,
     safe_unicode,
     )
+from bzrlib.symbol_versioning import (
+    deprecated_in,
+    deprecated_method,
+    )
 from bzrlib.transport.local import LocalTransport
 from bzrlib.tree import (
     InterTree,
@@ -415,7 +419,7 @@
                 return link_or_sha1
         return None
 
-    def _get_inventory(self):
+    def _get_root_inventory(self):
         """Get the inventory for the tree. This is only valid within a lock."""
         if 'evil' in debug.debug_flags:
             trace.mutter_callsite(2,
@@ -426,9 +430,16 @@
         self._generate_inventory()
         return self._inventory
 
+    @deprecated_method(deprecated_in((2, 5, 0)))
+    def _get_inventory(self):
+        return self.root_inventory
+
     inventory = property(_get_inventory,
                          doc="Inventory of this Tree")
 
+    root_inventory = property(_get_root_inventory,
+        "Root inventory of this tree")
+
     @needs_read_lock
     def get_parent_ids(self):
         """See Tree.get_parent_ids.
@@ -1150,7 +1161,8 @@
                 # _make_delta if we can't get the RevisionTree
                 pass
             else:
-                delta = rev_tree.inventory._make_delta(basis_tree.inventory)
+                delta = rev_tree.root_inventory._make_delta(
+                    basis_tree.root_inventory)
                 dirstate.update_basis_by_delta(delta, rev_id)
                 updated = True
         if not updated:

